@@ -5,9 +5,9 @@ module ProjectScoped
     before_action :set_project
     before_action :set_nodes
 
-    helper        :tylium
+    helper :hera
     helper_method :current_project
-    layout        'tylium'
+    layout 'hera/project'
   end
 
   protected
