@@ -3,9 +3,8 @@ class ProjectsController < AuthenticatedController
 
   before_action :set_project
 
-  helper        :tylium
+  helper        :hera
   helper_method :current_project
-  layout        'tylium'
 
   def index
     redirect_to project_path(current_project)
@@ -16,12 +15,12 @@ class ProjectsController < AuthenticatedController
     @authors       = [current_user]
     @boards        = current_project.methodology_library.boards
     @issues        = current_project.issues.includes(:tags).sort
-    @methodologies = current_project.methodology_library.notes.map{|n| Methodology.new(filename: n.id, content: n.text)}
+    @methodologies = current_project.methodology_library.notes.map { |n| Methodology.new(filename: n.id, content: n.text) }
     @nodes         = current_project.nodes.in_tree
     @tags          = current_project.tags
 
     @count_by_tag  = { unassigned: 0 }
-    @issues_by_tag = Hash.new{|h,k| h[k] = [] }
+    @issues_by_tag = Hash.new { |h, k| h[k] = [] }
 
     @tag_names = @tags.map do |tag|
       @count_by_tag[tag.name] = 0
@@ -41,7 +40,7 @@ class ProjectsController < AuthenticatedController
     end
 
     respond_to do |format|
-      format.html { render layout: 'tylium' if !request.xhr?}
+      format.html { render layout: 'hera/project' if !request.xhr? }
       format.json { render json: @boards }
     end
   end
