@@ -6,7 +6,7 @@ module MarkupHelper
     {
       form_url: main_app.form_fields_path(format: :js),
       help_url: main_app.help_markup_path,
-      preview_url: main_app.preview_markup_path(preview_params),
+      preview_url: @form_preview_path || main_app.preview_markup_path(preview_params),
       source_url: main_app.source_fields_path
     }
   end
