@@ -55,7 +55,7 @@ class Methodology
 
   def new_record?()
     # return true unless self.filename
-    return !File.exists?(full_path)
+    return !File.exist?(full_path)
   end
 
   # def destroyed?()  true end
@@ -120,7 +120,7 @@ class Methodology
 
   def save
     return false if !valid?
-    FileUtils.mkdir_p(Methodology.pwd) unless File.exists?(Methodology.pwd)
+    FileUtils.mkdir_p(Methodology.pwd) unless File.exist?(Methodology.pwd)
     File.open(full_path, 'w') do |f|
       f << @content
     end
@@ -128,7 +128,7 @@ class Methodology
   end
 
   def destroy
-    return true unless filename && File.exists?(full_path)
+    return true unless filename && File.exist?(full_path)
     File.delete(full_path)
     self
   end
