@@ -7,18 +7,22 @@
 # Unless the DB is already migrated, do nothing
 
 Rails.application.reloader.to_prepare do
-  if (ActiveRecord::Base.connection rescue false) && Configuration.table_exists? && Configuration.paths_templates.exist?
+  if (ActiveRecord::Base.connection.verify! rescue false) &&
+    Configuration.table_exists? &&
+    Configuration.paths_templates.exist? &&
+    Mapping.table_exists?
     # ---------------------------------------------------------------- 3.1 Upload
     template_dir = Configuration.paths_templates_plugins
-
-    Dradis::Plugins::with_feature(:upload).each do |plugin|
-      plugin.copy_templates(to: template_dir)
+    # mappings table may not exist when migrating from an old OVA to a new one so we need this guard
+    Dradis::Plugins::with_feature(:upload).each do |integration|
+      integration.copy_samples(to: template_dir)
+      integration.migrate_templates_to_mappings(from: template_dir) if !Rails.env.test?
     end
 
     # ---------------------------------------------------------------- 3.2 Export
     template_dir = Configuration.paths_templates_reports
     Dradis::Plugins::with_feature(:export).each do |plugin|
-      plugin.copy_templates(to: template_dir)
+      plugin.copy_samples(to: template_dir)
     end
   end
 end
