@@ -160,5 +160,12 @@ Rails.application.routes.draw do
     root to: 'setup/passwords#new'
   end
 
+  ErrorsController::SUPPORTED_ERRORS.each do |status_name, status_code|
+    match "/#{status_code}",
+      to: "errors##{status_name}",
+      via: :all,
+      defaults: { status_code: status_code }
+  end
+
   mount ActionCable.server => '/cable'
 end
