@@ -6,6 +6,10 @@ module Dradis
       VERSION::STRING
     end
   end
+
+  def self.edition
+    :ce
+  end
 end
 
 require 'html/ignore_liquid_in_textile_block_codes'
@@ -16,3 +20,5 @@ require 'html/pipeline/dradis/fieldable_filter'
 require 'html/pipeline/dradis/liquid_filter'
 require 'html/pipeline/dradis/mentions_filter'
 require 'html/pipeline/dradis/textile_filter'
+
+require 'authentication_strategies'
