@@ -5,13 +5,12 @@ describe NotificationsBroadcastingJob do #, type: :job do
     expect(described_class.new.queue_name).to eq('dradis_project')
   end
 
-
   describe '#perform' do
     it 'broadcasts to the notificationschannel' do
       expect(NotificationsChannel).to receive(:broadcast_to).twice
 
       commentable = create(:issue)
-      create_list(:subscription, 2, subscribable: commentable)
+      subscriptions = create_list(:subscription, 2, subscribable: commentable)
       notifiable = create(:comment, commentable: commentable)
       project = commentable.node.project
 
